@@ -3,7 +3,7 @@
  *               for mp3/ogg splitting without decoding
  *
  * Copyright (c) 2002-2005 M. Trotta - <mtrotta@users.sourceforge.net>
- * Copyright (c) 2005-2011 Alexandru Munteanu - io_fx@yahoo.fr
+ * Copyright (c) 2005-2012 Alexandru Munteanu - io_fx@yahoo.fr
  *
  *********************************************************/
 
@@ -143,8 +143,7 @@ But it actually should never need to: If filename is NULL, then this
 plugin should not have been detected
 \return NULL on error
 */
-static FILE *splt_mp3_open_file_read(splt_state *state, const char *filename,
-    int *error)
+static FILE *splt_mp3_open_file_read(splt_state *state, const char *filename, int *error)
 {
   FILE *file_input = NULL;
 
@@ -504,13 +503,13 @@ static int splt_mp3_put_original_libid3_frame(splt_state *state,
             char *genre = (char *)tag_value;
 
             int id3v1 = atoi(genre);
-            if ((id3v1 != 0) &&
+            if ((id3v1 > 0) &&
                 (id3v1 < SPLT_ID3V1_NUMBER_OF_GENRES) &&
                 (state->original_tags.tags.genre == NULL))
             {
               err = splt_tu_set_original_tags_field(state, SPLT_TAGS_GENRE, splt_id3v1_genres[id3v1]);
             }
-            else if (strcmp(genre, "0") == 0)
+            else if (strlen(genre) == 0)
             {
               err = splt_tu_set_original_tags_field(state, SPLT_TAGS_GENRE, SPLT_UNDEFINED_GENRE);
             }
@@ -1090,8 +1089,7 @@ The information is put into the "state" structure.
  - enables framemode if xing header is found 
  - xing header is often associated with VBR (variable bit rate)
 */
-static splt_mp3_state *splt_mp3_info(FILE *file_input, splt_state *state,
-    int framemode, int *error)
+static splt_mp3_state *splt_mp3_info(FILE *file_input, splt_state *state, int framemode, int *error)
 {
   splt_mp3_state *mp3state = state->codec;
 
@@ -1110,7 +1108,6 @@ static splt_mp3_state *splt_mp3_info(FILE *file_input, splt_state *state,
   //always quiet
   mp3state->syncdetect = 0;
 
-  //we initialise default values
   mp3state->frames = 1;
   mp3state->end = 0;
   mp3state->end_non_zero = 0;
@@ -1147,6 +1144,21 @@ static splt_mp3_state *splt_mp3_info(FILE *file_input, splt_state *state,
       goto function_end;
     }
 
+    if (mp3state->stream.error == MAD_ERROR_LOSTSYNC)
+    {
+#ifndef NO_ID3TAG
+      signed long tag_size = id3_tag_query(mp3state->stream.this_frame,
+          mp3state->stream.bufend - mp3state->stream.this_frame);
+      if (tag_size > 0)
+      {
+        mad_stream_skip(&mp3state->stream, tag_size);
+      }
+#else
+      splt_c_put_info_message_to_client(state,
+          _(" warning: lost sync and compiled without id3tag support - the split might be corrupt\n"));
+#endif
+    }
+
     if ((prev == 0) &&
         ((ret == 0) || (mp3state->stream.error == MAD_ERROR_BUFLEN)))
     {
@@ -1356,8 +1368,8 @@ static void splt_mp3_get_info(splt_state *state, FILE *file_input, int *error)
   //checks if valid mp3 file
   //before last argument, if framemode or not
   //last argument if we put messages to clients or not
-  state->codec = splt_mp3_info(file_input, state,
-        splt_o_get_int_option(state,SPLT_OPT_FRAME_MODE), error);
+  state->codec = splt_mp3_info(file_input, state, 
+      splt_o_get_int_option(state, SPLT_OPT_FRAME_MODE), error);
   //if error
   if ((*error < 0) || (state->codec == NULL))
   {
@@ -1702,6 +1714,7 @@ static double splt_mp3_split(const char *output_fname, splt_state *state,
   int adjustoption = splt_o_get_int_option(state, SPLT_OPT_PARAM_GAP);
   short seekable = ! splt_o_get_int_option(state, SPLT_OPT_INPUT_NOT_SEEKABLE);
   float threshold = splt_o_get_float_option(state, SPLT_OPT_PARAM_THRESHOLD);
+  int shots = splt_o_get_int_option(state, SPLT_OPT_PARAM_SHOTS);
 
   short fend_sec_is_not_eof =
     !splt_u_fend_sec_is_bigger_than_total_time(state, fend_sec);
@@ -2298,7 +2311,7 @@ bloc_end:
         if ((adjust) && (mp3state->frames >= fend))
         {
           int silence_points_found =
-            splt_mp3_scan_silence(state, end, 2 * adjust, threshold, 0.f, 0, error,
+            splt_mp3_scan_silence(state, end, 2 * adjust, threshold, 0.f, shots, 0, error,
                 splt_scan_silence_processor);
           //if error, go out
           if (silence_points_found == -1)
@@ -3161,21 +3174,21 @@ void splt_mp3_init(splt_state *state, int *error)
 
   state->syncerrors = 0;
 
-  //if we can open the file
-  if ((file_input = splt_mp3_open_file_read(state, filename, error)) != NULL)
+  if ((file_input = splt_mp3_open_file_read(state, filename, error)) == NULL)
   {
-    splt_mp3_get_info(state, file_input, error);
+    return;
+  }
 
-    if (*error >= 0)
+  splt_mp3_get_info(state, file_input, error);
+
+  if (*error >= 0)
+  {
+    splt_mp3_state *mp3state = state->codec;
+    mp3state->off = splt_o_get_float_option(state, SPLT_OPT_PARAM_OFFSET);
+
+    if (splt_t_get_total_time(state) > 0)
     {
-      splt_mp3_state *mp3state = state->codec;
-      mp3state->off = splt_o_get_float_option(state,SPLT_OPT_PARAM_OFFSET);
-
-      //we initialise frames to 1
-      if (splt_t_get_total_time(state) > 0)
-      {
-        mp3state->frames = 1;
-      }
+      mp3state->frames = 1;
     }
   }
 }
@@ -3346,12 +3359,13 @@ int splt_pl_scan_silence(splt_state *state, int *error)
   float offset = splt_o_get_float_option(state,SPLT_OPT_PARAM_OFFSET);
   float threshold = splt_o_get_float_option(state, SPLT_OPT_PARAM_THRESHOLD);
   float min_length = splt_o_get_float_option(state, SPLT_OPT_PARAM_MIN_LENGTH);
+  int shots = splt_o_get_int_option(state, SPLT_OPT_PARAM_SHOTS);
 
   splt_mp3_state *mp3state = state->codec;
   mp3state->off = offset;
 
   int found = splt_mp3_scan_silence(state, mp3state->mp3file.firsthead.ptr, 0,
-      threshold, min_length, 1, error, splt_scan_silence_processor);
+      threshold, min_length, shots, 1, error, splt_scan_silence_processor);
   if (*error < 0) { return -1; }
 
   return found;
@@ -3361,11 +3375,12 @@ int splt_pl_scan_silence(splt_state *state, int *error)
 int splt_pl_scan_trim_silence(splt_state *state, int *error)
 {
   float threshold = splt_o_get_float_option(state, SPLT_OPT_PARAM_THRESHOLD);
+  int shots = splt_o_get_int_option(state, SPLT_OPT_PARAM_SHOTS);
 
   splt_mp3_state *mp3state = state->codec;
 
   int found = splt_mp3_scan_silence(state, mp3state->mp3file.firsthead.ptr, 0,
-      threshold, 0, 1, error, splt_trim_silence_processor);
+      threshold, 0, shots, 1, error, splt_trim_silence_processor);
   if (*error < 0) { return -1; }
 
   return found;
