@@ -4,7 +4,7 @@
  *               for mp3/ogg splitting without decoding
  *
  * Copyright (c) 2002-2005 M. Trotta - <mtrotta@users.sourceforge.net>
- * Copyright (c) 2005-2011 Alexandru Munteanu - <io_fx@yahoo.fr>
+ * Copyright (c) 2005-2012 Alexandru Munteanu - <io_fx@yahoo.fr>
  *
  * Parts of this file have been copied from the 'vcut' 1.6
  * program provided with 'vorbis-tools' :
@@ -44,7 +44,7 @@
 #include "ogg_new_stream_handler.h"
 
 int splt_ogg_scan_silence(splt_state *state, short seconds, float threshold, 
-    float min, short output, ogg_page *page, ogg_int64_t granpos,
+    float min, int shots, short output, ogg_page *page, ogg_int64_t granpos,
     int *error, ogg_int64_t first_cut_granpos,
     short silence_processor(double time, int silence_was_found, short must_flush,
       splt_scan_silence_data *ssd, int *found, int *error));
